<?php

/**
 * Visitor Info administration settings.
 *
 * @return
 *   Form for administrator to set configuration options.
 */
function visitorinfo_settings($form, &$form_state) {
  // create a text field to enter in the now required IPInfodb API Key
  $form['visitorinfo_ipinfodb_key'] = array(
    '#type' => 'fieldset',
    '#title' => t('IPinfoDB API Key'),
  );

  $form['visitorinfo_ipinfodb_key']['visitorinfo_ipinfodb_apikey'] = array(
    '#type' => 'textfield',
    '#title' => t('IPInfo API Key'),
    '#size' => '100',
    '#description' => t('Please provide a valid IPInfoDB API key.  You can get a key by visiting <a href="@ipinfoapipath">IPInfoDB API sign up page.</a>', array('@ipinfoapipath' => url('http://www.ipinfodb.com/register.php'))),
    '#default_value' => variable_get('visitorinfo_ipinfodb_apikey', ''),
  );
  $form['visitorinfo_markers'] = array(
    '#type' => 'fieldset',
    '#title' => t('Default Map Settings'),
  );
  $form['visitorinfo_markers']['visitorinfo_map_width'] = array(
    '#type' => 'textfield',
    '#title' => t('Default width'),
    '#description' => t('The default width of a Google map, as a CSS length or percentage. Examples: <em>50px</em>, <em>5em</em>, <em>2.5in</em>, <em>95%</em>'),
    '#default_value' => variable_get('visitorinfo_map_width', '100%'),
    '#size' => '10',
  );
  $form['visitorinfo_markers']['visitorinfo_map_height'] = array(
    '#type' => 'textfield',
    '#title' => t('Default height'),
    '#description' => t('The default height of a Google map, as a CSS length or percentage. Examples: <em>50px</em>, <em>5em</em>, <em>2.5in</em>, <em>95%</em>'),
    '#default_value' => variable_get('visitorinfo_map_height', '300px'),
    '#size' => '10',
  );
  $form['visitorinfo_markers']['visitorinfo_map_markers'] = array(
    '#type' => 'textfield',
    '#title' => t('Number of visitors to show on map'),
    '#description' => t('Default: 200'),
    '#default_value' => variable_get('visitorinfo_map_markers', '200'),
    '#size' => '10',
  );

  $form['visitorinfo_markers']['visitorinfo_enable_zoom'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable Scroll wheel Zoom'),
    '#description' => t('Check to enable zooming with the mouse scroll wheel.'),
    '#default_value' => variable_get('visitorinfo_enable_zoom', '0'),
  );

  $form['visitorinfo_markers']['visitorinfo_map_type'] = array(
    '#title' => t('Default map type'),
    '#type' => "select",
    '#options' =>  array(
      'ROADMAP' => t('Normal'),
      'SATELLITE' => t('Satellite'),
      'HYBRID' => t('Hybrid'),
      'TERRAIN' => t('Terrain'),
    ),        
    '#description' => t('Default: Normal Road Map'),
    '#default_value' => variable_get('visitorinfo_map_type', 'ROADMAP'),
  );

  $form['visitorinfo_markers']['visitorinfo_start_lat'] = array(
    '#type' => 'textfield',
    '#title' => t('Starting Latitude'),
    '#description' => t('Default: 39.467864'),
    '#default_value' => variable_get('visitorinfo_start_lat', '39.467864'),
    '#size' => '12',
  );
  $form['visitorinfo_markers']['visitorinfo_start_long'] = array(
    '#type' => 'textfield',
    '#title' => t('Starting Longitude'),
    '#description' => t('Default: -99.843750'),
    '#default_value' => variable_get('visitorinfo_start_long', '-99.843750'),
    '#size' => '10',
  );
  $form['visitorinfo_markers']['visitorinfo_info'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Data to display'),
    '#options' => array(
      'ip' => t('IP Address'),
      'city' => t('City'),
      'state' => t('State'),
      'zip' => t('Zip'),
      'ccode' => t('Country Code'),
      'cname' => t('Country Name'),
      'latitude' => t('Latitude'),
      'longitude' => t('Longitude'),
    ),
    '#description' => t('Check each item you wish to display.'),
    '#default_value' => variable_get('visitorinfo_info', array('ip', 'city', 'state', 'zip', 'cname', 'ccode', 'latitude', 'longitude')),
  );  
  $form['visitorinfo_update_ip'] = array(
      '#type' => 'fieldset',
      '#title' => t('IP data update settings'),
    );
  $form['visitorinfo_update_ip']['visitorinfo_update_ip_interval_days'] = array(
      '#type' => 'textfield',
      '#title' => t('Update interval'),
      '#description' => t('Specifiy an interval in days after which the collected IP data should be updated. Set to 0 to prevent updates. Note that the ipinfodb database is updated monthly.'),
      '#default_value' => variable_get('visitorinfo_update_ip_interval_days', 30),
      '#size' => '10',
    );
  $form['visitorinfo_db_records'] = array(
        '#type' => 'fieldset',
        '#title' => t('Visitor Info database settings'),
  );
  $form['visitorinfo_db_records']['visitorinfo_max_db_records'] = array(
        '#type' => 'textfield',
        '#title' => t('Record number'),
        '#description' => t('Specifiy the number of visitors to store in the database. Enter 0 for unlimited.'),
        '#default_value' => variable_get('visitorinfo_max_db_records', 0),
        '#size' => '10',
  );
  
  
  
  return system_settings_form($form);
}